@@ -19,13 +19,12 @@
 #include "gameselectionscene.h"
 
 #include "dealerinfo.h"
+#include "kpat_debug.h"
 #include "renderer.h"
 
 #include <KColorUtils>
-#include <QDebug>
 #include <KLocalizedString>
 
-
 #include <QGraphicsObject>
 #include <QKeyEvent>
 #include <QPainter>
