@@ -48,24 +48,24 @@ class Spider : public DealerScene
 
 public:
     explicit Spider( const DealerInfo * di );
-    virtual void initialize();
-    virtual void mapOldId(int id);
-    virtual int oldId() const;
-    virtual QList<QAction*> configActions() const;
+    void initialize() Q_DECL_OVERRIDE;
+    void mapOldId(int id) Q_DECL_OVERRIDE;
+    int oldId() const Q_DECL_OVERRIDE;
+    QList<QAction*> configActions() const Q_DECL_OVERRIDE;
 
 protected:
-    virtual QString getGameState() const;
-    virtual void setGameState( const QString & state );
-    virtual QString getGameOptions() const;
-    virtual void setGameOptions( const QString & options );
-    virtual bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const;
-    virtual bool checkRemove(const PatPile * pile, const QList<KCard*> & cards) const;
-    virtual void cardsMoved( const QList<KCard*> & cards, KCardPile * oldPile, KCardPile * newPile );
-    virtual void restart( const QList<KCard*> & cards );
+    QString getGameState() const Q_DECL_OVERRIDE;
+    void setGameState( const QString & state ) Q_DECL_OVERRIDE;
+    QString getGameOptions() const Q_DECL_OVERRIDE;
+    void setGameOptions( const QString & options ) Q_DECL_OVERRIDE;
+    bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const Q_DECL_OVERRIDE;
+    bool checkRemove(const PatPile * pile, const QList<KCard*> & cards) const Q_DECL_OVERRIDE;
+    void cardsMoved( const QList<KCard*> & cards, KCardPile * oldPile, KCardPile * newPile ) Q_DECL_OVERRIDE;
+    void restart( const QList<KCard*> & cards ) Q_DECL_OVERRIDE;
 
 protected slots:
-    virtual bool newCards();
-    virtual void animationDone();
+    bool newCards() Q_DECL_OVERRIDE;
+    void animationDone() Q_DECL_OVERRIDE;
 
 private slots:
     void gameTypeChanged();
