@@ -38,13 +38,13 @@
 #include "statisticsdialog.h"
 
 #include "dealerinfo.h"
+#include "kpat_debug.h"
 #include "version.h"
 
 #include <KConfigGroup>
-#include <QDebug>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <QtCore/QList>
+#include <QList>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
